==> stepfunctions-0.8.2-sources.jar: software/amazon/awscdk/services/stepfunctions/cloudformation/ActivityResource.java <==
package software.amazon.awscdk.services.stepfunctions.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-stepfunctions-activity.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.cloudformation.ActivityResource")
public class ActivityResource extends software.amazon.awscdk.Resource {
    protected ActivityResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.cloudformation.ActivityResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::StepFunctions::Activity``.
     * @param parent the ``cdk.Construct`` this ``ActivityResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``ActivityResource``
     */
    public ActivityResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.stepfunctions.cloudformation.ActivityResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
    /**
     * @cloudformation_attribute Name
     */
    public software.amazon.awscdk.services.stepfunctions.ActivityName getActivityName() {
        return this.jsiiGet("activityName", software.amazon.awscdk.services.stepfunctions.ActivityName.class);
    }
}

==> stepfunctions-0.19.0-sources.jar: software/amazon/awscdk/services/stepfunctions/cloudformation/ActivityResource.java <==
package software.amazon.awscdk.services.stepfunctions.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-stepfunctions-activity.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.11 (build 44c3b9b)", date = "2018-12-04T12:20:29.255Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.cloudformation.ActivityResource")
public class ActivityResource extends software.amazon.awscdk.Resource {
    protected ActivityResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.cloudformation.ActivityResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::StepFunctions::Activity``.
     * @param parent the ``cdk.Construct`` this ``ActivityResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``ActivityResource``
     */
    public ActivityResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.stepfunctions.cloudformation.ActivityResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getActivityArn() {
        return this.jsiiGet("activityArn", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Name
     */
    public java.lang.String getActivityName() {
        return this.jsiiGet("activityName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.stepfunctions.cloudformation.ActivityResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.stepfunctions.cloudformation.ActivityResourceProps.class);
    }
}
